==> elemental2-dom-1.3.2.jar: elemental2/dom/VTTCue.java <==
/*
 * Copyright 2018 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package elemental2.dom;

import jsinterop.annotations.JsOverlay;
import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsType;
import jsinterop.base.Js;
import org.jspecify.annotations.Nullable;

@JsType(isNative = true, namespace = JsPackage.GLOBAL)
public class VTTCue extends TextTrackCue {
  @JsType(isNative = true, name = "?", namespace = JsPackage.GLOBAL)
  public interface LineUnionType {
    @JsOverlay
    static VTTCue.LineUnionType of(Object o) {
      return Js.cast(o);
    }

    @JsOverlay
    default double asDouble() {
      return Js.asDouble(this);
    }

    @JsOverlay
    default String asString() {
      return Js.asString(this);
    }

    @JsOverlay
    default boolean isDouble() {
      return (Object) this instanceof Double;
    }

    @JsOverlay
    default boolean isString() {
      return (Object) this instanceof String;
    }
  }

  @JsType(isNative = true, name = "?", namespace = JsPackage.GLOBAL)
  public interface PositionUnionType {
    @JsOverlay
    static VTTCue.PositionUnionType of(Object o) {
      return Js.cast(o);
    }

    @JsOverlay
    default double asDouble() {
      return Js.asDouble(this);
    }

    @JsOverlay
    default String asString() {
      return Js.asString(this);
    }

    @JsOverlay
    default boolean isDouble() {
      return (Object) this instanceof Double;
    }

    @JsOverlay
    default boolean isString() {
      return (Object) this instanceof String;
    }
  }

  public String align;
  public VTTCue.LineUnionType line;
  public String lineAlign;
  public VTTCue.PositionUnionType position;
  public String positionAlign;
  public @Nullable VTTRegion region;
  public int size;
  public boolean snapToLines;
  public String text;
  public String vertical;

  public VTTCue(double startTime, double endTime, String text) {
    // This super call is here only for the code to compile; it is never executed.
    super(0, 0, (String) null);
  }

  public native DocumentFragment getCueAsHTML();
}

==> elemental2-dom-2.27.jar: elemental2/dom/VTTCue.java <==
package elemental2.dom;

import jsinterop.annotations.JsOverlay;
import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsType;
import jsinterop.base.Js;

@JsType(isNative = true, namespace = JsPackage.GLOBAL)
public class VTTCue extends TextTrackCue {
  @JsType(isNative = true, name = "?", namespace = JsPackage.GLOBAL)
  public interface LineUnionType {
    @JsOverlay
    static VTTCue.LineUnionType of(Object o) {
      return Js.cast(o);
    }

    @JsOverlay
    default double asDouble() {
      return Js.asDouble(this);
    }

    @JsOverlay
    default String asString() {
      return Js.asString(this);
    }

    @JsOverlay
    default boolean isDouble() {
      return (Object) this instanceof Double;
    }

    @JsOverlay
    default boolean isString() {
      return (Object) this instanceof String;
    }
  }

  @JsType(isNative = true, name = "?", namespace = JsPackage.GLOBAL)
  public interface PositionUnionType {
    @JsOverlay
    static VTTCue.PositionUnionType of(Object o) {
      return Js.cast(o);
    }

    @JsOverlay
    default double asDouble() {
      return Js.asDouble(this);
    }

    @JsOverlay
    default String asString() {
      return Js.asString(this);
    }

    @JsOverlay
    default boolean isDouble() {
      return (Object) this instanceof Double;
    }

    @JsOverlay
    default boolean isString() {
      return (Object) this instanceof String;
    }
  }

  public String align;
  public VTTCue.LineUnionType line;
  public String lineAlign;
  public VTTCue.PositionUnionType position;
  public String positionAlign;
  public VTTRegion region;
  public int size;
  public boolean snapToLines;
  public String text;
  public String vertical;

  public VTTCue(double startTime, double endTime, String text) {
    // This super call is here only for the code to compile; it is never executed.
    super(0, 0, (String) null);
  }

  public native DocumentFragment getCueAsHTML();
}
